==> 3.5.12-core.tar: kdesdk/kbabel/datatools/accelerators/main.h <==
/* This file is part of KBabel
   based on Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
		    2002 	Stanislav Visnovsky <visnovsky@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
   the Qt library by Trolltech AS, Norway (or with modified versions
   of Qt that use the same license as Qt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
   Qt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
	
*/

#ifndef __main_h__
#define __main_h__

#include "kbproject.h"

#include <kdatatool.h>

#include <tqregexp.h>

class AcceleratorTool : public KDataTool
{
    Q_OBJECT

public:
    AcceleratorTool( TQObject* parent, const char* name, const TQStringList & );
    virtual bool run( const TQString& command, void* data, const TQString& datatype, const TQString& mimetype);

private:
    TQRegExp _context;
    TQChar _marker;
    KBabel::Project::Ptr _cache_origin;
};

#endif

==> 3.5.13-core.tar: kdesdk/kbabel/datatools/accelerators/main.h <==
/* This file is part of KBabel
   based on Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
		    2002 	Stanislav Visnovsky <visnovsky@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
   the TQt library by Trolltech AS, Norway (or with modified versions
   of TQt that use the same license as TQt), and distribute linked
   combinations including the two.  You must obey the GNU General
   Public License in all respects for all of the code used other than
   TQt. If you modify this file, you may extend this exception to
   your version of the file, but you are not obligated to do so.  If
   you do not wish to do so, delete this exception statement from
   your version.
	
*/

#ifndef __main_h__
#define __main_h__

#include "kbproject.h"

#include <kdatatool.h>

#include <tqregexp.h>

class AcceleratorTool : public KDataTool
{
    Q_OBJECT
  TQ_OBJECT

public:
    AcceleratorTool( TQObject* parent, const char* name, const TQStringList & );
    virtual bool run( const TQString& command, void* data, const TQString& datatype, const TQString& mimetype);

private:
    TQRegExp _context;
    TQChar _marker;
    KBabel::Project::Ptr _cache_origin;
};

#endif
